@@ -1,30 +1,30 @@
 package CHI::Driver;
-use strict;
-use warnings;
 use Carp;
 use CHI::CacheObject;
 use CHI::Util qw(parse_duration);
 use List::MoreUtils qw(pairwise);
-use base qw(Class::Accessor::Fast);
+use Moose;
+use Moose::Util::TypeConstraints;
+use strict;
+use warnings;
 
-__PACKAGE__->mk_ro_accessors(
-    qw(default_set_options short_driver_name namespace));
-__PACKAGE__->mk_accessors(qw(is_subcache on_get_error on_set_error));
+# Call this when updating default set options
+my @trigger_set_options =
+  ( trigger => sub { $_[0]->_compute_default_set_options() } );
 
-# When these are set, call _compute_default_set_options again.
-foreach my $field qw(expires_at expires_in expires_variance) {
-    no strict 'refs';
-    *{ __PACKAGE__ . "::$field" } = sub {
-        my $self = shift;
-        if (@_) {
-            $self->{$field} = $_[0];
-            $self->_compute_default_set_options();
-        }
-        else {
-            return $self->{$field};
-        }
-    };
-}
+type OnError => where { ref($_) eq 'CODE' || /^(?:ignore|warn|die|log)/ };
+
+has 'default_set_options' => ( is => 'ro' );
+has 'expires_at'          => ( is => 'rw', @trigger_set_options );
+has 'expires_in'          => ( is => 'rw', @trigger_set_options );
+has 'expires_variance'    => ( is => 'rw', @trigger_set_options );
+has 'is_subcache'         => ( is => 'rw' );
+has 'namespace'           => ( is => 'ro', isa => 'Str', default => 'Default' );
+has 'on_get_error'        => ( is => 'rw', isa => 'OnError', default => 'log' );
+has 'on_set_error'        => ( is => 'rw', isa => 'OnError', default => 'log' );
+has 'short_driver_name'   => ( is => 'ro' );
+
+__PACKAGE__->meta->make_immutable();
 
 # These methods must be implemented by subclass
 foreach my $method (qw(fetch store remove get_keys get_namespaces)) {
@@ -38,52 +38,12 @@ use constant Max_Time => 0xffffffff;
 # To override time() for testing - must be writable in a dynamically scoped way from tests
 our $Test_Time;    ## no critic (ProhibitPackageVars)
 
-sub new {
-    my $class = shift;
-
-    my $self = $class->SUPER::new(@_);
-
-    my %defaults = (
-        driver       => 'Memory',
-        namespace    => 'Default',
-        on_get_error => 'log',
-        on_set_error => 'log',
-    );
-    while ( my ( $key, $value ) = each(%defaults) ) {
-        $self->{$key} = $value if !defined( $self->{$key} );
-    }
-
-    # Default the namespace to the first non-chi caller, or 'Default' if none found
-    #
-    my $level = 0;
-    while ( !defined( $self->{namespace} ) ) {
-        $level++;
-        my $caller = caller($level);
-        if ( !defined($caller) ) {
-            $self->{namespace} = 'Default';
-        }
-        elsif (
-            $caller =~ /^CHI(?::|$)/
-            || (   $caller->can('isa_chi_class')
-                && $caller->isa_chi_class() )
-          )
-        {
-            next;
-        }
-        else {
-            $self->{namespace} = $caller;
-        }
-    }
+sub BUILD {
+    my ( $self, $params ) = @_;
 
     $self->_compute_default_set_options();
 
-    # TODO: validate:
-    # on_set_error      => 'warn'   ('ignore', 'warn', 'die', sub { })
-    # on_get_error      => 'warn'   ('ignore', 'warn', 'die', sub { })
-
     ( $self->{short_driver_name} = ref($self) ) =~ s/^CHI::Driver:://;
-
-    return $self;
 }
 
 sub _compute_default_set_options {
