@@ -1,6 +1,4 @@
 package CHI::Driver::File;
-use strict;
-use warnings;
 use Carp;
 use Cwd qw(realpath cwd);
 use CHI::Util
@@ -12,30 +10,36 @@ use File::Find qw(find);
 use File::Path qw(mkpath rmtree);
 use File::Slurp qw(read_dir);
 use File::Spec::Functions qw(catdir catfile splitdir tmpdir);
-use base qw(CHI::Driver);
+use Moose;
+use strict;
+use warnings;
 
-my $Default_Create_Mode = oct(775);
-my $Default_Depth       = 2;
-my $Default_Root_Dir    = catdir( tmpdir(), "chi-driver-file" );
-my $Max_File_Length     = 254;
+extends 'CHI::Driver';
 
-my $Fetch_Flags = O_RDONLY | O_BINARY;
-my $Store_Flags = O_WRONLY | O_CREAT | O_BINARY;
+has 'depth'            => ( is => 'ro', isa => 'Int', default => 2 );
+has 'dir_create_mode'  => ( is => 'ro', isa => 'Int', default => oct(775) );
+has 'file_create_mode' => ( is => 'ro', isa => 'Int', default => oct(666) );
+has 'root_dir'         => ( is => 'ro', isa => 'Str' );
+has 'path_to_namespace' => ( is => 'ro' );
 
-__PACKAGE__->mk_ro_accessors(
-    qw(dir_create_mode file_create_mode depth path_to_namespace root_dir));
+__PACKAGE__->meta->make_immutable();
 
-sub new {
-    my $class = shift;
-    my $self  = $class->SUPER::new(@_);
-    $self->{dir_create_mode}  ||= $Default_Create_Mode;
-    $self->{file_create_mode} ||= $self->{dir_create_mode} & oct(666);
-    $self->{depth}            ||= $Default_Depth;
+my $Max_File_Length = 254;
+my $Max_Path_Length = ( $^O eq 'MSWin32' ? 254 : 1023 );
+my $Fetch_Flags     = O_RDONLY | O_BINARY;
+my $Store_Flags     = O_WRONLY | O_CREAT | O_BINARY;
+
+sub BUILD {
+    my ( $self, $params ) = @_;
+
+    # Allow 'cache_root' for backward compatibility with Cache::Filecache
     $self->{root_dir} ||=
-      ( delete( $self->{cache_root} ) || $Default_Root_Dir );
+      ( delete( $self->{cache_root} )
+          || catdir( tmpdir(), "chi-driver-file" ) );
+
+    # Calculate directory corresponding to our namespace
     $self->{path_to_namespace} =
       catdir( $self->root_dir, escape_for_filename( $self->{namespace} ) );
-    return $self;
 }
 
 sub desc {
@@ -113,7 +117,7 @@ sub store {
 
     # Rename can fail in rare race conditions...try multiple times
     #
-    for ( my $try = 0 ; $try < 10 ; $try++ ) {
+    for ( my $try = 0 ; $try < 3 ; $try++ ) {
         last if ( rename( $temp_file, $file ) );
     }
     if ( -f $temp_file ) {
@@ -202,11 +206,11 @@ sub path_to_key {
     #
     my $filename = escape_for_filename($key) . ".dat";
     if ( length($filename) > $Max_File_Length ) {
-        my $log       = CHI->logger();
         my $namespace = $self->{namespace};
-        $log->warn(
-            "key '$key' in namespace '$namespace' is over $Max_File_Length chars when escaped; cannot cache"
-        );
+        CHI->logger()
+          ->warn(
+            "escaped key '$key' in namespace '$namespace' is over $Max_File_Length chars; cannot cache"
+          );
         return undef;
     }
 
@@ -222,6 +226,15 @@ sub path_to_key {
         $filepath = fast_catfile( @paths, $filename );
     }
 
+    if ( length($filepath) > $Max_Path_Length ) {
+        my $namespace = $self->{namespace};
+        CHI->logger()
+          ->warn(
+            "full escaped path for key '$key' in namespace '$namespace' is over $Max_Path_Length chars; cannot cache"
+          );
+        return undef;
+    }
+
     return $filepath;
 }
 
@@ -280,8 +293,8 @@ Permissions mode to use when creating directories. Defaults to 0775.
 
 =item file_create_mode
 
-Permissions mode to change cache files to after creation, using chmod, e.g. 0666 or
-0664. Default is to not use chmod and just create files with the current umask.
+Permissions mode to use when creating files, modified by the current umask. Defaults to
+0666.
 
 =item depth
 
