@@ -1,11 +1,14 @@
 package CHI::Test::Logger;
-use strict;
-use warnings;
 use CHI::Util qw(dump_one_line);
 use List::MoreUtils qw(first_index);
 use Test::Deep qw(cmp_deeply);
-use base qw(Class::Accessor);
-__PACKAGE__->mk_ro_accessors(qw(msgs));
+use strict;
+use warnings;
+use Moose;
+use strict;
+use warnings;
+
+has 'msgs' => ( is => 'ro' );
 
 foreach my $level (qw(fatal error warn info debug)) {
     no strict 'refs';
